Installation — MzFont 0.0.1 documentation

# Installation

MzFont depends on FontForge. For Debian based systems, the following command will install this dependency.

    apt install fontforge

The software is distributed via PyPI, it can be installed with `pip`:

    pip install mzfont

## From source

The source is hosted on GitHub, to install the latest development version, use the following commands.

    git clone https://github.com/jfjlaros/mzfont
    cd mzfont
    pip install .